# AUTOGENERATED! DO NOT EDIT! File to edit: ../03_transformers.ipynb.

# %% auto 0
__all__ = ['EmptyFitMixin']

# %% ../03_transformers.ipynb 4
class EmptyFitMixin:
    def fit(self, x, y=None):
        return self
