# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/ds_tut',
                'doc_host': 'https://ephes.github.io',
                'git_url': 'https://github.com/ephes/ds_tut',
                'lib_path': 'ds_tut'},
  'syms': { 'ds_tut.core': {'ds_tut.core.foo': ('core.html#foo', 'ds_tut/core.py')},
            'ds_tut.datasets': { 'ds_tut.datasets.ReutersCorpus': ('datasets.html#reuterscorpus', 'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersCorpus.__init__': ('datasets.html#reuterscorpus.__init__', 'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersCorpus._add_modapte': ( 'datasets.html#reuterscorpus._add_modapte',
                                                                                 'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersCorpus._add_text': ('datasets.html#reuterscorpus._add_text', 'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersCorpus._add_topics': ( 'datasets.html#reuterscorpus._add_topics',
                                                                                'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersCorpus._renumber_topics': ( 'datasets.html#reuterscorpus._renumber_topics',
                                                                                     'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersCorpus.build_dataframe': ( 'datasets.html#reuterscorpus.build_dataframe',
                                                                                    'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersCorpus.filter_empty_cats': ( 'datasets.html#reuterscorpus.filter_empty_cats',
                                                                                      'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersCorpus.filter_multi_label': ( 'datasets.html#reuterscorpus.filter_multi_label',
                                                                                       'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersCorpus.get_docs': ('datasets.html#reuterscorpus.get_docs', 'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersCorpus.get_labels': ( 'datasets.html#reuterscorpus.get_labels',
                                                                               'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersCorpus.get_single_label': ( 'datasets.html#reuterscorpus.get_single_label',
                                                                                     'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersCorpus.number_of_classes': ( 'datasets.html#reuterscorpus.number_of_classes',
                                                                                      'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersCorpus.number_of_samples': ( 'datasets.html#reuterscorpus.number_of_samples',
                                                                                      'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersCorpus.split_modapte': ( 'datasets.html#reuterscorpus.split_modapte',
                                                                                  'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersCorpus.texts': ('datasets.html#reuterscorpus.texts', 'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersCorpus.top_n': ('datasets.html#reuterscorpus.top_n', 'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersCorpus.topic_counts': ( 'datasets.html#reuterscorpus.topic_counts',
                                                                                 'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersParser': ('datasets.html#reutersparser', 'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersParser.cleanup_sgml': ( 'datasets.html#reutersparser.cleanup_sgml',
                                                                                 'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersParser.get_text': ('datasets.html#reutersparser.get_text', 'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersParser.get_topics': ( 'datasets.html#reutersparser.get_topics',
                                                                               'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersParser.parse_doc': ('datasets.html#reutersparser.parse_doc', 'ds_tut/datasets.py'),
                                 'ds_tut.datasets.ReutersParser.parse_sgml': ( 'datasets.html#reutersparser.parse_sgml',
                                                                               'ds_tut/datasets.py'),
                                 'ds_tut.datasets.build_reuters_dataframe': ( 'datasets.html#build_reuters_dataframe',
                                                                              'ds_tut/datasets.py')},
            'ds_tut.io': {'ds_tut.io.download_from_url': ('io.html#download_from_url', 'ds_tut/io.py')},
            'ds_tut.setup': { 'ds_tut.setup.running_in_colab': ('setup.html#running_in_colab', 'ds_tut/setup.py'),
                              'ds_tut.setup.set_retina_mode': ('setup.html#set_retina_mode', 'ds_tut/setup.py'),
                              'ds_tut.setup.setup': ('setup.html#setup', 'ds_tut/setup.py'),
                              'ds_tut.setup.setup_colab': ('setup.html#setup_colab', 'ds_tut/setup.py')},
            'ds_tut.transformers': { 'ds_tut.transformers.EmptyFitMixin': ('transformers.html#emptyfitmixin', 'ds_tut/transformers.py'),
                                     'ds_tut.transformers.EmptyFitMixin.fit': ( 'transformers.html#emptyfitmixin.fit',
                                                                                'ds_tut/transformers.py')}}}
